%define pkg       ntpd
%define ver       4.2.6p5
%define maj       %(echo %{ver} | cut -d'.' -f1)
%define min       %(echo %{ver} | cut -d'.' -f2)

%define sel_modn  selinux-policy-addon
%define sel_modv  0.2.0


Summary:          System time synchronization using the Network Time Protocol (NTP)
Name:             ntp
Version:          %{ver}
Release:          1%{?dist}%{?pext}
License:          distributable
Group:            System Environment/Daemons
Source0:          http://archive.%{name}.org/%{name}%{maj}/%{name}-%{version}.tar.gz
Source1:          ntpstat-0.2.tgz
Source10:         %{pkg}.init
Source11:         %{pkg}.sysconfig
Source12:         %{name}.conf
Source13:         %{name}.keys
Patch0:           %{name}-4.0.99m-usegethost.patch
Patch1:           %{name}-4.2.6p4-droproot.patch
Patch2:           %{name}-4.2.4p6-paths.patch
Patch3:           %{name}-4.2.6-seedfile.patch
URL:              http://www.%{name}.org/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           David L. Mills <mills@udel.edu>
Provides:         ntpserver ntpclient sntpclient
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service
BuildRequires:    libcap-devel ncurses-devel openssl-devel
BuildRequires:    readline-devel

%description
The Network Time Protocol (NTP) is used to synchronize a computer's time with
another reference time source. This package contains utilities and daemons to
synchronize the computer's time to Coordinated Universal Time (UTC) via the NTP
protocol and other NTP servers. It includes ntpdate (a program for retrieving
the date and time from remote machines via a network) and ntpd (a daemon which
continuously adjusts system time).


%package          selinux
Summary:          SELinux support for the NTPv4 daemon
Group:            System Environment/Base
Requires:         %{name} = %{version}-%{release}
Requires:         %{sel_modn} >= %{sel_modv}
Requires(post):   /sbin/restorecon %{_sbindir}/selinuxenabled

%description      selinux
This package enables the NTPv4 daemon to work with SELinux.


%prep
%setup -q -a 1
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1


%build
# Build env (NTP)
BOPT="-DOPENSSL_NO_KRB5 -g"
BOPT="${BOPT} -DDEFAULT_LOGDIR='\"%{_localstatedir}/log/%{name}\"'"
BOPT="${BOPT} -DDEFAULT_SEEDFILE='\"%{_localstatedir}/lib/%{name}/random\"'"
# Build env (SNTP)
BOPT="${BOPT} -DLOCKNAME='\"%{_localstatedir}/run/msntp.pid\"'"
BOPT="${BOPT} -DSAVENAME='\"%{_localstatedir}/lib/%{name}/msntp.state\"'"
BOPT="${BOPT} -DHAVE_VSNPRINTF=1"

%configure \
	CFLAGS="${CFLAGS} ${BOPT}"          \
	--sysconfdir=%{_sysconfdir}/%{name} \
	--bindir=%{_sbindir}                \
	--enable-linuxcaps                  \
	--enable-debugging                  \
	--enable-all-clocks                 \
	--enable-parse-clocks               \
	--enable-ipv6                       \
	--enable-simulator                  \
	--enable-ntp-signd                  \
	--with-sntp                         \
	--with-crypto                       \
	--with-binsubdir=sbin               \
	--with-lineeditlibs=readline        \
	--with-openssl-libdir=%{_libdir}    \
	--disable-libopts-install

%{__make} %{?_smp_mflags}

# Build ntpstat
pushd ntpstat-*
%{__make} %{?_smp_mflags}
popd


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{%{name},sysconfig}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_bindir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/%{name}/contrib
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_mandir}/man1
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/{lib,log}/%{name}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

%{__install} -m 0755 %{SOURCE10}     ${RPM_BUILD_ROOT}%{_initrddir}/%{pkg}
%{__install} -m 0644 %{SOURCE11}     ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{pkg}

%{__install} -m 0640 %{SOURCE12}     ${RPM_BUILD_ROOT}%{_sysconfdir}
%{__install} -m 0640 %{SOURCE13}     ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/keys

pushd scripts
%{__cp}      -rpd {monitoring,stats} ${RPM_BUILD_ROOT}%{_datadir}/%{name}/contrib
%{__cp}      -rpd {README,calc_tickadj,checktime,ntp-groper,ntp-status} \
				     ${RPM_BUILD_ROOT}%{_datadir}/%{name}/contrib
%{__cp}      -rpd {ntp-wait,ntpsweep,ntpver,plot_summary,summary}       \
				     ${RPM_BUILD_ROOT}%{_datadir}/%{name}/contrib
popd

pushd ntpstat-*
%{__install} -m 0755 ntpstat         ${RPM_BUILD_ROOT}%{_bindir}
%{__install} -m 0644 *.1             ${RPM_BUILD_ROOT}%{_mandir}/man1
popd

echo                 "0.000"        >${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}/drift
touch                                ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/step-tickers


%pre
if ! getent group  %{name} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r -g 38 %{name}
fi
if ! getent passwd %{name} >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -u 38 -g %{name} \
	-d %{_localstatedir}/lib/%{name} \
	-c "NTP Service user"            \
	-s /sbin/nologin %{name}
fi
exit 0			# Always pass


%post
/sbin/chkconfig --add %{pkg}

%post selinux
if /usr/sbin/selinuxenabled && [ -e /selinux/policyvers ]; then
  /sbin/fixfiles   -R %{name} restore
  /sbin/restorecon -R %{_localstatedir}/lib/%{name}
  /sbin/restorecon -R %{_localstatedir}/log/%{name}
fi


%preun
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{pkg} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{pkg}
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service %{pkg} condrestart >/dev/null 2>&1 || :
fi


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc COPYRIGHT ChangeLog CommitLog* INSTALL
%doc NEWS NOTES* README* TODO WHERE-TO-START
%doc %dir html
%{_initrddir}/%{pkg}
%config(noreplace) %{_sysconfdir}/sysconfig/%{pkg}
%attr(640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}.conf
%attr(750,root,%{name}) %dir %{_sysconfdir}/%{name}
%attr(640,root,%{name}) %config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/%{name}/keys
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/%{name}/step-tickers
%{_bindir}/ntpstat
%{_sbindir}/ntp-keygen
%{_sbindir}/ntp-wait
%{_sbindir}/ntpdate
%{_sbindir}/ntpdc
%{_sbindir}/ntpq
%{_sbindir}/ntptime
%{_sbindir}/ntptrace
%{_sbindir}/tickadj
%{_sbindir}/sntp
%{_sbindir}/%{pkg}
%{_sbindir}/ntpdsim
%{_datadir}/%{name}
%{_mandir}/man1/*.1*
%attr(750,%{name},%{name}) %dir %{_localstatedir}/lib/%{name}
%attr(750,%{name},%{name}) %dir %{_localstatedir}/log/%{name}
%attr(640,%{name},%{name}) %config(noreplace) %verify(not md5 size mtime) %{_localstatedir}/lib/%{name}/drift

%files selinux
%defattr(-,root,root)


%changelog
* Tue Dec 27 2011 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.6p5-1
- New version (4.2.6p5)

* Tue Oct 18 2011 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.6p4-2
- Added fix for bug #2034

* Wed Oct 05 2011 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.6p4-1
- New version (4.2.6p4)

* Wed Jan 19 2011 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.6p3-1
- New version (4.2.6p3)

* Fri Jul 30 2010 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.6p2-1
- New version (4.2.6p2)

* Tue Apr 13 2010 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.6p1-1
- New version (4.2.6p1)

* Sat Dec 19 2009 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.6-1
- New version (4.2.6)

* Wed Dec 09 2009 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.4p8-1
- New version (4.2.4p8)

* Tue May 19 2009 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.4p7-1
- New version (4.2.4p7)

* Sat Feb 21 2009 Peter Pramberger <peterpramb@member.fsf.org> - 4.2.4p6-1
- New version (4.2.4p6)

* Thu Oct 11 2007 peter.pramberger@member.fsf.org 4.2.4p4-6
- new version (4.2.4p4)

* Thu Jul 26 2007 peter.pramberger@member.fsf.org 4.2.4p3-6
- new version (4.2.4p3)

* Thu May 03 2007 peter.pramberger@member.fsf.org 4.2.4p0-6
- new version (4.2.4p0)

* Tue Feb 06 2007 peter.pramberger@member.fsf.org 4.2.4-6
- new version (4.2.4)

* Thu Nov 02 2006 peter.pramberger@member.fsf.org
- new version (4.2.2p4)

* Mon Sep 25 2006 peter.pramberger@member.fsf.org
- new version (4.2.2p3)
- added contrib scripts
- removed outdated manpages

* Mon Jun 12 2006 peter.pramberger@member.fsf.org
- new version (4.2.2)

* Wed Apr 05 2006 peter.pramberger@member.fsf.org
- new version (dev-4.2.0b-rc1-20060404)

* Thu Feb 16 2006 peter.pramberger@member.fsf.org
- new version (dev-4.2.0b-20060216)

* Sat Feb 11 2006 peter.pramberger@member.fsf.org
- created
